@@ -1,4 +1,5 @@
 from collections import namedtuple
+import enum
 import inspect
 import logging
 import math
@@ -8,6 +9,7 @@ from typing import Any, Dict, List, Optional, Tuple, Set
 from bravado.exception import HTTPNotFound
 
 from django.db import models
+
 from django.contrib.staticfiles.storage import staticfiles_storage
 
 from . import __title__
@@ -21,9 +23,10 @@ from .app_settings import (
     EVEUNIVERSE_LOAD_STARGATES,
     EVEUNIVERSE_LOAD_STARS,
     EVEUNIVERSE_LOAD_STATIONS,
+    EVEUNIVERSE_USE_EVESKINSERVER,
 )
 from .constants import EVE_CATEGORY_ID_BLUEPRINT, EVE_CATEGORY_ID_SKIN
-from .core import eveimageserver
+from .core import eveimageserver, eveskinserver
 from .managers import (
     EveUniverseBaseModelManager,
     EveUniverseEntityModelManager,
@@ -1031,17 +1034,17 @@ class EveSolarSystem(EveUniverseEntityModel):
     @property
     def is_high_sec(self) -> bool:
         """returns True if this solar system is in high sec, else False"""
-        return self.security_status > 0.5
+        return round(self.security_status, 1) >= 0.5
 
     @property
     def is_low_sec(self) -> bool:
         """returns True if this solar system is in low sec, else False"""
-        return 0 < self.security_status <= 0.5
+        return 0 < round(self.security_status, 1) < 0.5
 
     @property
     def is_null_sec(self) -> bool:
         """returns True if this solar system is in null sec, else False"""
-        return self.security_status <= 0 and not self.is_w_space
+        return round(self.security_status, 1) <= 0 and not self.is_w_space
 
     @property
     def is_w_space(self) -> bool:
@@ -1310,7 +1313,7 @@ class EveType(EveUniverseEntityModel):
     packaged_volume = models.FloatField(default=None, null=True)
     portion_size = models.PositiveIntegerField(default=None, null=True)
     radius = models.FloatField(default=None, null=True)
-    published = models.BooleanField()
+    published = models.BooleanField()  # TODO: Add index
     volume = models.FloatField(default=None, null=True)
 
     class EveUniverseMeta:
@@ -1328,42 +1331,70 @@ class EveType(EveUniverseEntityModel):
         }
         load_order = 134
 
+    class IconVariant(enum.Enum):
+
+        REGULAR = enum.auto()
+        """anything, except blueprint or skin"""
+
+        BPO = enum.auto()
+        """blueprint original"""
+
+        BPC = enum.auto()
+        """blueprint copy"""
+
+        SKIN = enum.auto()
+        """SKIN"""
+
     def icon_url(
         self,
-        size=EveUniverseEntityModel.DEFAULT_ICON_SIZE,
-        category_id=None,
-        is_blueprint=None,
+        size: int = EveUniverseEntityModel.DEFAULT_ICON_SIZE,
+        variant: IconVariant = None,
+        category_id: int = None,
+        is_blueprint: bool = None,
     ) -> str:
-        """return an image URL to this type as icon. Also works for blueprints.
+        """returns an image URL to this type as icon. Also works for blueprints and SKINs.
 
-        This method accesses eve_group unless is_regular, is_blueprint or is_skin is set
+        Will try to auto-detect the variant based on the types's category,
+        unless `variant` or `category_id` is specified.
 
         Args:
-            category_id: category ID of this type (avoids extra DB call)
+            variant: icon variant to use
+            category_id: category ID of this type
             is_blueprint: DEPRECATED - type is assumed to be a blueprint
-
-        Note that a generic icon will returned for all SKIN types, which supports sizes
-        of 32, 64, 128 only.
         """
         # if is_blueprint is not None:
         #    warnings.warn("is_blueprint in EveType.icon_url() is deprecated")
 
         if is_blueprint:
-            category_id = EVE_CATEGORY_ID_BLUEPRINT
+            variant = self.IconVariant.BPO
 
-        if category_id is None:
-            category_id = self.eve_group.eve_category_id
+        if not variant:
+            if not category_id:
+                category_id = self.eve_group.eve_category_id
 
-        if category_id == EVE_CATEGORY_ID_BLUEPRINT:
+            if category_id == EVE_CATEGORY_ID_BLUEPRINT:
+                variant = self.IconVariant.BPO
+
+            elif category_id == EVE_CATEGORY_ID_SKIN:
+                variant = self.IconVariant.SKIN
+
+        if variant is self.IconVariant.BPO:
             return eveimageserver.type_bp_url(self.id, size=size)
-        elif category_id == EVE_CATEGORY_ID_SKIN:
-            if not size or size < 32 or size > 128 or (size & (size - 1) != 0):
+
+        if variant is self.IconVariant.BPC:
+            return eveimageserver.type_bpc_url(self.id, size=size)
+
+        if variant is self.IconVariant.SKIN:
+            size = EveUniverseEntityModel.DEFAULT_ICON_SIZE if not size else size
+            if EVEUNIVERSE_USE_EVESKINSERVER:
+                return eveskinserver.type_icon_url(self.id, size=size)
+
+            if size < 32 or size > 128 or (size & (size - 1) != 0):
                 raise ValueError("Invalid size: {}".format(size))
-            else:
-                filename = f"eveuniverse/skin_generic_{size}.png"
-                return staticfiles_storage.url(filename)
-        else:
-            return eveimageserver.type_icon_url(self.id, size=size)
+            filename = f"eveuniverse/skin_generic_{size}.png"
+            return staticfiles_storage.url(filename)
+
+        return eveimageserver.type_icon_url(self.id, size=size)
 
     def render_url(self, size=EveUniverseEntityModel.DEFAULT_ICON_SIZE) -> str:
         """return an image URL to this type as render"""
